/*-
 * Copyright (c) 2006 Robert N. M. Watson
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <stdio.h>
#include <stdlib.h>

#include "cons.h"
#include "dos.h"
#include "emul.h"

/*
 * Initialization function and defaults for various emulation subsystems.
 */

static const char *dos_mappings[] = {
	"/usr/home/robert/wwiv/a",
	"/usr/home/robert/wwiv/b",
	"/usr/home/robert/wwiv/c",
	"/usr/home/robert/wwiv/d",
	"/usr/home/robert/wwiv/e",
	NULL
};

static const char *dos_starting_directory = "C:\\WWIV";
static const char *dos_logfile = "/tmp/wwiv_dos.log";
static const char *com_devname = "/dev/nmdm0A";

void
emul_init(void)
{

	bios_init();
	com_init(com_devname);
	cons_init();
	dos_init(dos_logfile, dos_mappings, dos_starting_directory);
}

void
panic(const char *format, ...)
{
	va_list ap;

	printf("panic: ");
	va_start(ap, format);
	vprintf(format, ap);
	va_end(ap);
	printf("\n");
	exit(-1);
}
